Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(13)

Unified Diff: services/ui/display/screen_manager_ozone_internal.h

Issue 2685003002: Rename ScreeManagerOzone to ScreenManagerOzoneInternal (Closed)
Patch Set: patch for landing Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « services/ui/display/screen_manager_ozone.cc ('k') | services/ui/display/screen_manager_ozone_internal.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: services/ui/display/screen_manager_ozone_internal.h
diff --git a/services/ui/display/screen_manager_ozone.h b/services/ui/display/screen_manager_ozone_internal.h
similarity index 88%
rename from services/ui/display/screen_manager_ozone.h
rename to services/ui/display/screen_manager_ozone_internal.h
index 013607672e0309f895e502bc975a355a2a7d43f2..239ad78acf9ae2176c08423e68c9c9959579b134 100644
--- a/services/ui/display/screen_manager_ozone.h
+++ b/services/ui/display/screen_manager_ozone_internal.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef SERVICES_UI_DISPLAY_SCREEN_MANAGER_OZONE_H_
-#define SERVICES_UI_DISPLAY_SCREEN_MANAGER_OZONE_H_
+#ifndef SERVICES_UI_DISPLAY_SCREEN_MANAGER_OZONE_INTERNAL_H_
+#define SERVICES_UI_DISPLAY_SCREEN_MANAGER_OZONE_INTERNAL_H_
#include <stdint.h>
@@ -30,9 +30,10 @@ class FakeDisplayController;
class ScreenBase;
class TouchTransformController;
-// ScreenManagerOzone provides the necessary functionality to configure all
-// attached physical displays on the ozone platform.
-class ScreenManagerOzone
+// ScreenManagerOzoneInternal provides the necessary functionality to configure
+// all attached physical displays on the the ozone platform when operating in
+// internal window mode.
+class ScreenManagerOzoneInternal
: public ScreenManager,
public mojom::TestDisplayController,
public mojom::DisplayController,
@@ -41,8 +42,8 @@ class ScreenManagerOzone
public service_manager::InterfaceFactory<mojom::DisplayController>,
public service_manager::InterfaceFactory<mojom::TestDisplayController> {
public:
- ScreenManagerOzone();
- ~ScreenManagerOzone() override;
+ ScreenManagerOzoneInternal();
+ ~ScreenManagerOzoneInternal() override;
void SetPrimaryDisplayId(int64_t display_id);
@@ -71,7 +72,7 @@ class ScreenManagerOzone
const RelinquishDisplayControlCallback& callback) override;
private:
- friend class ScreenManagerOzoneTest;
+ friend class ScreenManagerOzoneInternalTest;
ViewportMetrics GetViewportMetricsForDisplay(const Display& display);
@@ -116,9 +117,9 @@ class ScreenManagerOzone
mojo::BindingSet<mojom::DisplayController> controller_bindings_;
mojo::BindingSet<mojom::TestDisplayController> test_bindings_;
- DISALLOW_COPY_AND_ASSIGN(ScreenManagerOzone);
+ DISALLOW_COPY_AND_ASSIGN(ScreenManagerOzoneInternal);
};
} // namespace display
-#endif // SERVICES_UI_DISPLAY_SCREEN_MANAGER_OZONE_H_
+#endif // SERVICES_UI_DISPLAY_SCREEN_MANAGER_OZONE_INTERNAL_H_
« no previous file with comments | « services/ui/display/screen_manager_ozone.cc ('k') | services/ui/display/screen_manager_ozone_internal.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698